@@ -14,7 +14,7 @@ import dataclasses
 import math
 import warnings
 from dataclasses import dataclass, field
-from typing import TYPE_CHECKING, Any, Callable, Literal, overload
+from typing import TYPE_CHECKING, Any, Callable, Iterable, Literal, overload
 
 import numpy as np
 from numpy.typing import NDArray
@@ -22,7 +22,8 @@ from numpy.typing import NDArray
 from .annotation_classes import AnnotatedIon, RetentionTime
 from .config import Config, get_default_config
 from .peptide import Peptide
-from .utils import annotate_peaks, clear_lazy_cache, get_tolerance, lazy, mz
+from .utils.class_utils import clear_lazy_cache, lazy
+from .utils.mz_utils import annotate_peaks, get_tolerance, mz, stack_mz_pairs
 
 if TYPE_CHECKING:
     from matplotlib import pyplot as plt
@@ -407,12 +408,20 @@ class Spectrum:
         return np.array(outs)
 
     @staticmethod
-    def _sample():
+    def _sample(random: bool = False) -> Spectrum:
         """Returns a sample Spectrum object."""
         config = Config()
+        if random:
+            num_peaks = np.random.randint(low=1, high=5)
+            mz = np.random.uniform(low=0, high=1000, size=num_peaks)
+            intensity = np.random.uniform(low=0, high=1000, size=num_peaks)
+        else:
+            mz = np.array([50.0, 147.11333, 1000.0, 1500.0, 2000.0])
+            intensity = np.array([50.0, 200.0, 1.0, 2.0, 3.0])
+
         spectrum = Spectrum(
-            mz=np.array([50.0, 147.11333, 1000.0, 1500.0, 2000.0]),
-            intensity=np.array([50.0, 200.0, 1.0, 2.0, 3.0]),
+            mz=mz,
+            intensity=intensity,
             ms_level=2,
             extras={"EXTRAS": ["extra1", "extra2"]},
             config=config,
@@ -469,6 +478,59 @@ class Spectrum:
         msmsspec = self.to_sus()
         return plotspec(msmsspec, ax=ax, **kwargs)
 
+    @classmethod
+    def stack(cls, spectra: Iterable[Spectrum]) -> Spectrum:
+        """Stacks multiple spectra into a single spectrum.
+
+        Args:
+            spectra: An iterable of spectra to stack.
+
+        Returns:
+            A stacked spectrum.
+
+        Examples:
+            >>> np.random.seed(0)
+            >>> spectrum1 = Spectrum._sample()
+            >>> spectrum2 = Spectrum._sample(random=True)
+            >>> spectrum3 = Spectrum._sample(random=True)
+            >>> spectrum4 = Spectrum._sample(random=False)
+            >>> spectrum4.mz = spectrum1.mz + 1e-4
+            >>> mzs, ints = Spectrum.stack([spectrum1, spectrum2, spectrum3, spectrum4])
+            >>> mzs
+            array([  50.        ,  147.11333   ,  423.65479934,  437.58721126,
+                    544.883183  ,  592.84461823,  645.89411307, 1000.        ,
+                   1500.        , 2000.        ])
+            >>> ints
+            array([[ 50.        ,   0.        ,   0.        ,  50.        ],
+                   [200.        ,   0.        ,   0.        , 200.        ],
+                   [  0.        ,   0.        , 963.6627605 ,   0.        ],
+                   [  0.        ,   0.        , 791.72503808,   0.        ],
+                   [  0.        ,   0.        , 891.77300078,   0.        ],
+                   [  0.        , 844.26574858,   0.        ,   0.        ],
+                   [  0.        ,   0.        , 383.44151883,   0.        ],
+                   [  1.        ,   0.        ,   0.        ,   1.        ],
+                   [  2.        ,   0.        ,   0.        ,   2.        ],
+                   [  3.        ,   0.        ,   0.        ,   3.        ]])
+            >>> ints.shape
+            (10, 4)
+
+        """
+        spectra = list(spectra)
+        ref_spec = spectra[0]
+        assert all([s.ms_level == spectra[0].ms_level for s in spectra])
+        assert all([s.config == spectra[0].config for s in spectra])
+
+        mz_pairs = [(s.mz, s.intensity) for s in spectra]
+        mz, new_int = stack_mz_pairs(
+            mz_pairs,
+            tolerance=ref_spec.config.g_tolerances[ref_spec.ms_level - 1],
+            units=ref_spec.config.g_tolerance_units[ref_spec.ms_level - 1],
+        )
+        order = np.argsort(mz)
+        mz = mz[order]
+        new_int = new_int[order]
+        return mz, new_int
+
 
 def _bin_spectrum(
     mz: NDArray[np.float64],
